@@ -3,6 +3,7 @@ from typing import Optional
 from pbxonline.models.base import ObjectListModel, BaseModel
 from .base import APIEndpoint
 from pbxonline.models.utils import construct_object_from_data, construct_error_from_data
+from pbxonline.utils import request_not_succesful
 
 class PBXEndpoint(APIEndpoint):
     
@@ -13,6 +14,13 @@ class PBXEndpoint(APIEndpoint):
     def get_sip_accounts(self) -> ObjectListModel:
         
         status, headers, resp_json = self.api.get( f'{self.endpoint}/sipaccount')
-        if status > 299: return construct_error_from_data(resp_json)
+        if request_not_succesful(status): return construct_error_from_data(resp_json)
+
+        return construct_object_from_data(resp_json['results'])
+    
+    def get_did_numbers(self) -> ObjectListModel:
+        
+        status, headers, resp_json = self.api.get( f'{self.endpoint}/did')
+        if request_not_succesful(status): return construct_error_from_data(resp_json)
 
         return construct_object_from_data(resp_json['results'])
\ No newline at end of file
